rai\_toolbox.optim.L2ProjectedOptim
===================================

.. currentmodule:: rai_toolbox.optim

.. autoclass:: L2ProjectedOptim

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L2ProjectedOptim.__init__

   
   